from setuptools import setup

setup(name='few_dists',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['few_dists'],
      author='Chandrama Naha',
      author_email='chandrama.naha@gmail.com',
      zip_safe=False)
